@@ -425,11 +425,13 @@ void KeyframeWidget::connectMonitor(bool active)
 
 void KeyframeWidget::slotUpdateKeyframesFromMonitor(const QPersistentModelIndex &index, const QVariant &res)
 {
-    GenTime pos(getPosition(), pCore->getCurrentFps());
     if (m_keyframes->isEmpty()) {
+        // Always ensure first keyframe is at clip start
+        GenTime pos(pCore->getItemIn(m_model->getOwnerId()), pCore->getCurrentFps());
         m_keyframes->addKeyframe(pos, KeyframeType::Linear);
         m_keyframes->updateKeyframe(pos, res, index);
     } else if (m_keyframes->hasKeyframe(getPosition()) || m_keyframes->singleKeyframe()) {
+        GenTime pos(getPosition(), pCore->getCurrentFps());
         m_keyframes->updateKeyframe(pos, res, index);
     }
 }
@@ -475,7 +477,7 @@ void KeyframeWidget::slotImportKeyframes()
         return;
     }
     import->importSelectedData();
-    
+
     /*m_model->getKeyframeModel()->getKeyModel()->dataChanged(QModelIndex(), QModelIndex());*/
     /*m_model->modelChanged();
     qDebug()<<"//// UPDATING KEYFRAMES CORE---------";
@@ -485,5 +487,6 @@ void KeyframeWidget::slotImportKeyframes()
 
 void KeyframeWidget::slotRemoveNextKeyframes()
 {
-    m_keyframes->removeNextKeyframes(GenTime(m_time->getValue(), pCore->getCurrentFps()));
+    int pos = m_time->getValue() + m_model->data(m_index, AssetParameterModel::ParentInRole).toInt();
+    m_keyframes->removeNextKeyframes(GenTime(pos, pCore->getCurrentFps()));
 }
