@@ -53,6 +53,7 @@ Core::Core()
 void Core::prepareShutdown()
 {
     m_guiConstructed = false;
+    QThreadPool::globalInstance()->clear();
 }
 
 Core::~Core()
@@ -195,6 +196,7 @@ void Core::initGUI(const QUrl &Url)
     }
     QMetaObject::invokeMethod(pCore->projectManager(), "slotLoadOnOpen", Qt::QueuedConnection);
     m_mainWindow->show();
+    QThreadPool::globalInstance()->setMaxThreadCount(qMin(4, QThreadPool::globalInstance()->maxThreadCount()));
 }
 
 std::unique_ptr<Core> &Core::self()
@@ -395,6 +397,8 @@ int Core::getItemIn(const ObjectId &id)
     case ObjectType::TimelineClip:
         if (m_mainWindow->getCurrentTimeline()->controller()->getModel()->isClip(id.second)) {
             return m_mainWindow->getCurrentTimeline()->controller()->getModel()->getClipIn(id.second);
+        } else {
+            qDebug()<<"// ERROR QUERYING NON CLIP PROPERTIES\n\n!!!!!!!!!!!!!!!!!!!!!!!!!!";
         }
         break;
     case ObjectType::TimelineComposition:
