@@ -95,10 +95,11 @@ bool DocumentChecker::hasErrorInClips()
     // Check if strorage folder for temp files exists
     QString storageFolder;
     QDir projectDir(m_url.adjusted(QUrl::RemoveFilename).toLocalFile());
+    QString documentid;
     QDomNodeList playlists = m_doc.elementsByTagName(QStringLiteral("playlist"));
     for (int i = 0; i < playlists.count(); ++i) {
         if (playlists.at(i).toElement().attribute(QStringLiteral("id")) == BinPlaylist::binPlaylistId) {
-            QString documentid = Xml::getXmlProperty(playlists.at(i).toElement(), QStringLiteral("kdenlive:docproperties.documentid"));
+            documentid = Xml::getXmlProperty(playlists.at(i).toElement(), QStringLiteral("kdenlive:docproperties.documentid"));
             if (documentid.isEmpty()) {
                 // invalid document id, recreate one
                 documentid = QString::number(QDateTime::currentMSecsSinceEpoch());
@@ -177,12 +178,11 @@ bool DocumentChecker::hasErrorInClips()
                         } else {
                             Xml::setXmlProperty(e, QStringLiteral("mlt_service"), QStringLiteral("avformat"));
                         }
-                        
                     }
                 }
                 continue;
             }
-            
+
             checkMissingImagesAndFonts(QStringList(), QStringList(Xml::getXmlProperty(e, QStringLiteral("family"))), e.attribute(QStringLiteral("id")),
                                        e.attribute(QStringLiteral("name")));
             continue;
@@ -253,7 +253,7 @@ bool DocumentChecker::hasErrorInClips()
             if (!QFile::exists(original)) {
                 // clip has proxy but original clip is missing
                 missingSources.append(e);
-                missingPaths.append(resource);
+                missingPaths.append(original);
             }
             verifiedPaths.append(resource);
             continue;
@@ -264,9 +264,13 @@ bool DocumentChecker::hasErrorInClips()
             resource = QFileInfo(resource).absolutePath();
         }
         if (!QFile::exists(resource)) {
-            // Missing clip found
-            m_missingClips.append(e);
-            missingPaths.append(resource);
+            // Missing clip found, make sure to omit timeline preview
+            if (QFileInfo(resource).absolutePath().endsWith(QString("/%1/preview").arg(documentid))) {
+                // This is a timeline preview missing chunk, ignore
+            } else {
+                m_missingClips.append(e);
+                missingPaths.append(resource);
+            }
         }
         // Make sure we don't query same path twice
         verifiedPaths.append(resource);
@@ -294,6 +298,7 @@ bool DocumentChecker::hasErrorInClips()
 
     QMap<QString, QString> autoFixLuma;
     QString lumaPath;
+    QString lumaMltPath;
     // Check existence of luma files
     for (const QString &lumafile : filesToCheck) {
         filePath = lumafile;
@@ -311,18 +316,31 @@ bool DocumentChecker::hasErrorInClips()
                 autoFixLuma.insert(filePath, fixedLuma);
                 continue;
             }
-            // Check MLT folder
+            // Check Kdenlive folder
             if (lumaPath.isEmpty()) {
                 QDir dir(QCoreApplication::applicationDirPath());
                 dir.cdUp();
                 dir.cd(QStringLiteral("share/kdenlive/lumas/"));
-                lumaPath = dir.absolutePath();
+                lumaPath = dir.absolutePath() + QStringLiteral("/");
             }
+            lumaName = filePath.section(QLatin1Char('/'), -2);
             lumaName.prepend(lumaPath);
             if (QFile::exists(lumaName)) {
                 autoFixLuma.insert(filePath, lumaName);
                 continue;
             }
+            // Check MLT folder
+            if (lumaMltPath.isEmpty()) {
+                QDir dir(KdenliveSettings::mltpath());
+                dir.cd(QStringLiteral("../lumas/"));
+                lumaMltPath = dir.absolutePath() + QStringLiteral("/");
+            }
+            lumaName = filePath.section(QLatin1Char('/'), -2);
+            lumaName.prepend(lumaMltPath);
+            if (QFile::exists(lumaName)) {
+                autoFixLuma.insert(filePath, lumaName);
+                continue;
+            }
 
             if (filePath.endsWith(QLatin1String(".pgm"))) {
                 fixedLuma = filePath.section(QLatin1Char('.'), 0, -2) + QStringLiteral(".png");
@@ -546,7 +564,7 @@ bool DocumentChecker::hasErrorInClips()
     for (int i = 0; i < max; ++i) {
         QDomElement e = missingProxies.at(i).toElement();
         QString realPath = Xml::getXmlProperty(e, QStringLiteral("kdenlive:originalurl"));
-        QString id = e.attribute(QStringLiteral("id"));
+        QString id = Xml::getXmlProperty(e, QStringLiteral("kdenlive:id"));
         m_missingProxyIds << id;
         // Tell Kdenlive to recreate proxy
         e.setAttribute(QStringLiteral("_replaceproxy"), QStringLiteral("1"));
@@ -556,7 +574,7 @@ bool DocumentChecker::hasErrorInClips()
         for (int j = 0; j < prodsCount; ++j) {
             mltProd = documentProducers.at(j).toElement();
             QString prodId = mltProd.attribute(QStringLiteral("id"));
-            QString parentId = prodId;
+            QString parentId = Xml::getXmlProperty(mltProd, QStringLiteral("kdenlive:id"));
             bool slowmotion = false;
             if (parentId.startsWith(QLatin1String("slowmotion"))) {
                 slowmotion = true;
@@ -568,14 +586,15 @@ bool DocumentChecker::hasErrorInClips()
             if (parentId == id) {
                 // Hit, we must replace url
                 QString suffix;
-                QString resource = Xml::getXmlProperty(mltProd, QStringLiteral("resource"));
                 if (slowmotion) {
+                    QString resource = Xml::getXmlProperty(mltProd, QStringLiteral("resource"));
                     suffix = QLatin1Char('?') + resource.section(QLatin1Char('?'), -1);
                 }
                 Xml::setXmlProperty(mltProd, QStringLiteral("resource"), realPath + suffix);
-                if (prodId == id) {
-                    // Only set proxy property on master producer
-                    Xml::setXmlProperty(mltProd, QStringLiteral("kdenlive:proxy"), QStringLiteral("-"));
+                Xml::setXmlProperty(mltProd, QStringLiteral("kdenlive:proxy"), QStringLiteral("-"));
+                if (missingPaths.contains(realPath)) {
+                    // Proxy AND source missing
+                    setProperty(mltProd, QStringLiteral("_placeholder"), QStringLiteral("1"));
                 }
             }
         }
