@@ -14,8 +14,8 @@ the Free Software Foundation, either version 3 of the License, or
 #include <QString>
 #include <cstdlib>
 
-AudioStreamInfo::AudioStreamInfo(Mlt::Producer *producer, int audioStreamIndex) :
-    m_audioStreamIndex(audioStreamIndex)
+AudioStreamInfo::AudioStreamInfo(const std::shared_ptr<Mlt::Producer> &producer, int audioStreamIndex)
+    : m_audioStreamIndex(audioStreamIndex)
     , m_ffmpegAudioIndex(0)
     , m_samplingRate(48000)
     , m_channels(2)
@@ -35,24 +35,11 @@ AudioStreamInfo::AudioStreamInfo(Mlt::Producer *producer, int audioStreamIndex)
         key = QStringLiteral("meta.media.%1.codec.channels").arg(audioStreamIndex).toLocal8Bit();
         m_channels = producer->get_int(key.data());
 
-        int streams = producer->get_int("meta.media.nb_streams");
-        QList<int> audioStreams;
-        for (int i = 0; i < streams; ++i) {
-            QByteArray propertyName = QStringLiteral("meta.media.%1.stream.type").arg(i).toLocal8Bit();
-            QString type = producer->get(propertyName.data());
-            if (type == QLatin1String("audio")) {
-                audioStreams << i;
-            }
-        }
-        if (audioStreams.count() > 1) {
-            m_ffmpegAudioIndex = audioStreams.indexOf(m_audioStreamIndex);
-        }
+        setAudioIndex(producer, m_audioStreamIndex);
     }
 }
 
-AudioStreamInfo::~AudioStreamInfo()
-{
-}
+AudioStreamInfo::~AudioStreamInfo() = default;
 
 int AudioStreamInfo::samplingRate() const
 {
@@ -81,8 +68,25 @@ int AudioStreamInfo::ffmpeg_audio_index() const
 
 void AudioStreamInfo::dumpInfo() const
 {
-    qCDebug(KDENLIVE_LOG) << "Info for audio stream " << m_audioStreamIndex
-                          << "\n\tChannels: " << m_channels
-                          << "\n\tSampling rate: " << m_samplingRate
+    qCDebug(KDENLIVE_LOG) << "Info for audio stream " << m_audioStreamIndex << "\n\tChannels: " << m_channels << "\n\tSampling rate: " << m_samplingRate
                           << "\n\tBit rate: " << m_bitRate;
 }
+
+void AudioStreamInfo::setAudioIndex(const std::shared_ptr<Mlt::Producer> &producer, int ix)
+{
+    m_audioStreamIndex = ix;
+    if (ix > -1) {
+        int streams = producer->get_int("meta.media.nb_streams");
+        QList<int> audioStreams;
+        for (int i = 0; i < streams; ++i) {
+            QByteArray propertyName = QStringLiteral("meta.media.%1.stream.type").arg(i).toLocal8Bit();
+            QString type = producer->get(propertyName.data());
+            if (type == QLatin1String("audio")) {
+                audioStreams << i;
+            }
+        }
+        if (audioStreams.count() > 1 && m_audioStreamIndex < audioStreams.count()) {
+            m_ffmpegAudioIndex = audioStreams.indexOf(m_audioStreamIndex);
+        }
+    }
+}
