@@ -484,6 +484,8 @@ signals:
     /** @brief Clear asset view if itemId is displayed. */
     void clearAssetPanel(int itemId = -1);
     void adjustAssetPanelRange(int itemId, int in, int out);
+    /** @brief Enable or disable the undo stack. For example undo/redo should not be enabled when dragging a clip in timeline or we risk corruption. */
+    void enableUndo(bool enable);
 };
 
 #endif
