@@ -33,6 +33,7 @@
 #include <KLocalizedString>
 #include <KMessageBox>
 #include <QDebug>
+#include <QProgressDialog>
 #include <QSet>
 #include <mlt++/MltPlaylist.h>
 #include <mlt++/MltProducer.h>
@@ -42,11 +43,11 @@
 static QStringList m_errorMessage;
 
 bool constructTrackFromMelt(const std::shared_ptr<TimelineItemModel> &timeline, int tid, Mlt::Tractor &track,
-                            const std::unordered_map<QString, QString> &binIdCorresp, Fun &undo, Fun &redo, bool audioTrack);
+                            const std::unordered_map<QString, QString> &binIdCorresp, Fun &undo, Fun &redo, bool audioTrack, QProgressDialog *progressDialog = nullptr);
 bool constructTrackFromMelt(const std::shared_ptr<TimelineItemModel> &timeline, int tid, Mlt::Playlist &track,
-                            const std::unordered_map<QString, QString> &binIdCorresp, Fun &undo, Fun &redo, bool audioTrack);
+                            const std::unordered_map<QString, QString> &binIdCorresp, Fun &undo, Fun &redo, bool audioTrack, QProgressDialog *progressDialog = nullptr);
 
-bool constructTimelineFromMelt(const std::shared_ptr<TimelineItemModel> &timeline, Mlt::Tractor tractor)
+bool constructTimelineFromMelt(const std::shared_ptr<TimelineItemModel> &timeline, Mlt::Tractor tractor, QProgressDialog *progressDialog)
 {
     Fun undo = []() { return true; };
     Fun redo = []() { return true; };
@@ -54,11 +55,10 @@ bool constructTimelineFromMelt(const std::shared_ptr<TimelineItemModel> &timelin
     timeline->requestReset(undo, redo);
     m_errorMessage.clear();
     std::unordered_map<QString, QString> binIdCorresp;
-    pCore->projectItemModel()->loadBinPlaylist(&tractor, timeline->tractor(), binIdCorresp);
+    pCore->projectItemModel()->loadBinPlaylist(&tractor, timeline->tractor(), binIdCorresp, progressDialog);
 
     QSet<QString> reserved_names{QLatin1String("playlistmain"), QLatin1String("timeline_preview"), QLatin1String("timeline_overlay"),
                                  QLatin1String("black_track")};
-
     bool ok = true;
     qDebug() << "//////////////////////\nTrying to construct" << tractor.count() << "tracks.\n////////////////////////////////";
     for (int i = 0; i < tractor.count() && ok; i++) {
@@ -79,7 +79,7 @@ bool constructTimelineFromMelt(const std::shared_ptr<TimelineItemModel> &timelin
             ok = timeline->requestTrackInsertion(-1, tid, QString(), audioTrack, undo, redo, false);
             int lockState = track->get_int("kdenlive:locked_track");
             Mlt::Tractor local_tractor(*track);
-            ok = ok && constructTrackFromMelt(timeline, tid, local_tractor, binIdCorresp, undo, redo, audioTrack);
+            ok = ok && constructTrackFromMelt(timeline, tid, local_tractor, binIdCorresp, undo, redo, audioTrack, progressDialog);
             timeline->setTrackProperty(tid, QStringLiteral("kdenlive:thumbs_format"), track->get("kdenlive:thumbs_format"));
             timeline->setTrackProperty(tid, QStringLiteral("kdenlive:audio_rec"), track->get("kdenlive:audio_rec"));
             if (lockState > 0) {
@@ -100,7 +100,7 @@ bool constructTimelineFromMelt(const std::shared_ptr<TimelineItemModel> &timelin
                 timeline->setTrackProperty(tid, QStringLiteral("hide"), QString::number(muteState));
             }
             int lockState = local_playlist.get_int("kdenlive:locked_track");
-            ok = ok && constructTrackFromMelt(timeline, tid, local_playlist, binIdCorresp, undo, redo, audioTrack);
+            ok = ok && constructTrackFromMelt(timeline, tid, local_playlist, binIdCorresp, undo, redo, audioTrack, progressDialog);
             timeline->setTrackProperty(tid, QStringLiteral("kdenlive:thumbs_format"), local_playlist.get("kdenlive:thumbs_format"));
             timeline->setTrackProperty(tid, QStringLiteral("kdenlive:audio_rec"), track->get("kdenlive:audio_rec"));
             if (lockState > 0) {
@@ -134,36 +134,33 @@ bool constructTimelineFromMelt(const std::shared_ptr<TimelineItemModel> &timelin
     }
     // Sort compositions and insert
     bool compositionOk = true;
-    if (!compositions.isEmpty()) {
-        std::sort(compositions.begin(), compositions.end(), [](Mlt::Transition *a, Mlt::Transition *b) { return a->get_b_track() > b->get_b_track(); });
-        while (!compositions.isEmpty()) {
-            QScopedPointer<Mlt::Transition> t(compositions.takeFirst());
-            auto transProps = std::make_unique<Mlt::Properties>(t->get_properties());
-            QString id(t->get("kdenlive_id"));
-            int compoId;
-            int aTrack = t->get_a_track();
-            if (aTrack > tractor.count()) {
-                m_errorMessage << i18n("Invalid composition %1 found on track %2 at %3, compositing with track %4.", t->get("id"), t->get_b_track(),
+    while (!compositions.isEmpty()) {
+        QScopedPointer<Mlt::Transition> t(compositions.takeFirst());
+        auto transProps = std::make_unique<Mlt::Properties>(t->get_properties());
+        QString id(t->get("kdenlive_id"));
+        int compoId;
+        int aTrack = t->get_a_track();
+        if (aTrack > tractor.count()) {
+            m_errorMessage << i18n("Invalid composition %1 found on track %2 at %3, compositing with track %4.", t->get("id"), t->get_b_track(),
                                        t->get_in(), t->get_a_track());
-                continue;
-            }
-
-            compositionOk = timeline->requestCompositionInsertion(id, timeline->getTrackIndexFromPosition(t->get_b_track() - 1), t->get_a_track(), t->get_in(),
-                                                                  t->get_length(), std::move(transProps), compoId, undo, redo);
-            if (!compositionOk) {
-                qDebug() << "ERROR : failed to insert composition in track " << t->get_b_track() << ", position" << t->get_in() << ", ID: " << id
-                         << ", MLT ID: " << t->get("id");
-                // timeline->requestItemDeletion(compoId, false);
-                m_errorMessage << i18n("Invalid composition %1 found on track %2 at %3.", t->get("id"), t->get_b_track(), t->get_in());
-                continue;
-            }
-            qDebug() << "Inserted composition in track " << t->get_b_track() << ", position" << t->get_in() << "/" << t->get_out();
+            continue;
         }
+
+        compositionOk = timeline->requestCompositionInsertion(id, timeline->getTrackIndexFromPosition(t->get_b_track() - 1), t->get_a_track(), t->get_in(),
+                                                                  t->get_length(), std::move(transProps), compoId, undo, redo);
+        if (!compositionOk) {
+            qDebug() << "ERROR : failed to insert composition in track " << t->get_b_track() << ", position" << t->get_in() << ", ID: " << id
+                         << ", MLT ID: " << t->get("id");
+            // timeline->requestItemDeletion(compoId, false);
+            m_errorMessage << i18n("Invalid composition %1 found on track %2 at %3.", t->get("id"), t->get_b_track(), t->get_in());
+            continue;
+        }
+        qDebug() << "Inserted composition in track " << t->get_b_track() << ", position" << t->get_in() << "/" << t->get_out();
     }
 
     // build internal track compositing
     timeline->buildTrackCompositing();
-    timeline->updateDuration();
+    //timeline->updateDuration();
 
     if (!ok) {
         // TODO log error
@@ -178,7 +175,7 @@ bool constructTimelineFromMelt(const std::shared_ptr<TimelineItemModel> &timelin
 }
 
 bool constructTrackFromMelt(const std::shared_ptr<TimelineItemModel> &timeline, int tid, Mlt::Tractor &track,
-                            const std::unordered_map<QString, QString> &binIdCorresp, Fun &undo, Fun &redo, bool audioTrack)
+                            const std::unordered_map<QString, QString> &binIdCorresp, Fun &undo, Fun &redo, bool audioTrack, QProgressDialog *progressDialog)
 {
     if (track.count() != 2) {
         // we expect a tractor with two tracks (a "fake" track)
@@ -192,7 +189,7 @@ bool constructTrackFromMelt(const std::shared_ptr<TimelineItemModel> &timeline,
             return false;
         }
         Mlt::Playlist playlist(*sub_track);
-        constructTrackFromMelt(timeline, tid, playlist, binIdCorresp, undo, redo, audioTrack);
+        constructTrackFromMelt(timeline, tid, playlist, binIdCorresp, undo, redo, audioTrack, progressDialog);
         if (i == 0) {
             // Pass track properties
             int height = track.get_int("kdenlive:trackheight");
@@ -253,12 +250,15 @@ PlaylistState::ClipState inferState(const std::shared_ptr<Mlt::Producer> &prod,
 } // namespace
 
 bool constructTrackFromMelt(const std::shared_ptr<TimelineItemModel> &timeline, int tid, Mlt::Playlist &track,
-                            const std::unordered_map<QString, QString> &binIdCorresp, Fun &undo, Fun &redo, bool audioTrack)
+                            const std::unordered_map<QString, QString> &binIdCorresp, Fun &undo, Fun &redo, bool audioTrack, QProgressDialog *progressDialog)
 {
     for (int i = 0; i < track.count(); i++) {
         if (track.is_blank(i)) {
             continue;
         }
+        if (progressDialog) {
+            progressDialog->setValue(progressDialog->value() + 1);
+        }
         std::shared_ptr<Mlt::Producer> clip(track.get_clip(i));
         int position = track.clip_start(i);
         switch (clip->type()) {
@@ -277,8 +277,19 @@ bool constructTrackFromMelt(const std::shared_ptr<TimelineItemModel> &timeline,
                 if (clipId.isEmpty()) {
                     clipId = clip->get("kdenlive:id");
                 }
-                Q_ASSERT(!clipId.isEmpty() && binIdCorresp.count(clipId) > 0);
-                binId = binIdCorresp.at(clipId);
+                if (binIdCorresp.count(clipId) == 0) {
+                    QStringList ids = pCore->projectItemModel()->getClipByUrl(QFileInfo(clip->parent().get("resource")));
+                    if (!ids.isEmpty()) {
+                        binId = ids.first();
+                        m_errorMessage << i18n("Invalid clip %1 found on track %2 at %3.", clip->parent().get("id"), track.get("id"), position);
+                    } else {
+                        qWarning()<<"Warning, clip in timeline has no parent in bin: "<<clip->parent().get("id");
+                        m_errorMessage << i18n("Invalid clip %1 found on track %2 at %3.", clip->parent().get("id"), track.get("id"), position);
+                    }
+                } else {
+                    binId = binIdCorresp.at(clipId);
+                }
+                Q_ASSERT(!clipId.isEmpty() && !binId.isEmpty());
                 clip->parent().set("kdenlive:id", binId.toUtf8().constData());
                 clip->parent().set("_kdenlive_processed", 1);
             }
@@ -298,7 +309,6 @@ bool constructTrackFromMelt(const std::shared_ptr<TimelineItemModel> &timeline,
                 break;
             }
             qDebug() << "Inserted clip in track" << tid << "at " << position;
-
             break;
         }
         case tractor_type: {
