@@ -112,8 +112,8 @@ int ClipModel::construct(const std::shared_ptr<TimelineModel> &parent, const QSt
     auto result = binClip->giveMasterAndGetTimelineProducer(id, producer, state);
     std::shared_ptr<ClipModel> clip(new ClipModel(parent, result.first, binClipId, id, state, speed));
     clip->setClipState_lambda(state)();
-    clip->m_effectStack->importEffects(producer, state, result.second);
     parent->registerClip(clip);
+    clip->m_effectStack->importEffects(producer, state, result.second);
     clip->m_clipMarkerModel->setReferenceModel(binClip->getMarkerModel(), speed);
     return id;
 }
@@ -190,9 +190,23 @@ bool ClipModel::requestResize(int size, bool right, Fun &undo, Fun &redo, bool l
             m_producer->set("length", outPoint + 1);
         }
     }
-    Fun operation = [this, inPoint, outPoint, track_operation]() {
+    QVector<int> roles{TimelineModel::DurationRole};
+    if (!right) {
+        roles.push_back(TimelineModel::StartRole);
+        roles.push_back(TimelineModel::InPointRole);
+    } else {
+        roles.push_back(TimelineModel::OutPointRole);
+    }
+    
+    Fun operation = [this, inPoint, outPoint, roles, track_operation]() {
         if (track_operation()) {
             setInOut(inPoint, outPoint);
+            if (m_currentTrackId > -1) {
+                if (auto ptr = m_parent.lock()) {
+                    QModelIndex ix = ptr->makeClipIndexFromID(m_id);
+                    ptr->notifyChange(ix, ix, roles);
+                }
+            }
             return true;
         }
         return false;
@@ -200,23 +214,19 @@ bool ClipModel::requestResize(int size, bool right, Fun &undo, Fun &redo, bool l
     if (operation()) {
         // Now, we are in the state in which the timeline should be when we try to revert current action. So we can build the reverse action from here
         if (m_currentTrackId != -1) {
-            QVector<int> roles{TimelineModel::DurationRole};
-            if (!right) {
-                roles.push_back(TimelineModel::StartRole);
-                roles.push_back(TimelineModel::InPointRole);
-            } else {
-                roles.push_back(TimelineModel::OutPointRole);
-            }
             if (auto ptr = m_parent.lock()) {
-                QModelIndex ix = ptr->makeClipIndexFromID(m_id);
-                // TODO: integrate in undo
-                ptr->dataChanged(ix, ix, roles);
                 track_reverse = ptr->getTrackById(m_currentTrackId)->requestClipResize_lambda(m_id, old_in, old_out, right);
             }
         }
-        Fun reverse = [this, old_in, old_out, track_reverse]() {
+        Fun reverse = [this, old_in, old_out, track_reverse, roles]() {
             if (track_reverse()) {
                 setInOut(old_in, old_out);
+                if (m_currentTrackId > -1) {
+                    if (auto ptr = m_parent.lock()) {
+                        QModelIndex ix = ptr->makeClipIndexFromID(m_id);
+                        ptr->notifyChange(ix, ix, roles);
+                    }
+                }
                 return true;
             }
             return false;
@@ -309,7 +319,8 @@ bool ClipModel::addEffect(const QString &effectId)
 bool ClipModel::copyEffect(const std::shared_ptr<EffectStackModel> &stackModel, int rowId)
 {
     QWriteLocker locker(&m_lock);
-    m_effectStack->copyEffect(stackModel->getEffectStackRow(rowId), m_currentState);
+    QDomDocument doc;
+    m_effectStack->copyXmlEffect(stackModel->rowToXml(rowId, doc));
     return true;
 }
 
@@ -438,6 +449,7 @@ bool ClipModel::useTimewarpProducer(double speed, Fun &undo, Fun &redo)
             local_undo();
             return false;
         }
+        adjustEffectLength(false, oldIn, getIn(), oldOut - oldIn, m_producer->get_playtime(), 0, local_undo, local_redo, true);
         UPDATE_UNDO_REDO(local_redo, local_undo, undo, redo);
         return true;
     }
@@ -548,8 +560,9 @@ void ClipModel::setCurrentTrackId(int tid, bool finalMove)
         }
     }
 
-    if (finalMove && tid != -1) {
+    if (finalMove && tid != -1 && m_lastTrackId != m_currentTrackId) {
         refreshProducerFromBin(m_currentState);
+        m_lastTrackId = m_currentTrackId;
     }
 }
 
@@ -559,6 +572,8 @@ Fun ClipModel::setClipState_lambda(PlaylistState::ClipState state)
     return [this, state]() {
         if (auto ptr = m_parent.lock()) {
             m_currentState = state;
+            // Enforce producer reload
+            m_lastTrackId = -1;
             if (m_currentTrackId != -1 && ptr->isClip(m_id)) { // if this is false, the clip is being created. Don't update model in that case
                 refreshProducerFromBin(m_currentState);
                 QModelIndex ix = ptr->makeClipIndexFromID(m_id);
@@ -733,6 +748,9 @@ void ClipModel::setOffset(int offset)
 void ClipModel::setGrab(bool grab)
 {
     QWriteLocker locker(&m_lock);
+    if (grab == m_grabbed) {
+        return;
+    }
     m_grabbed = grab;
     if (auto ptr = m_parent.lock()) {
         QModelIndex ix = ptr->makeClipIndexFromID(m_id);
@@ -740,6 +758,21 @@ void ClipModel::setGrab(bool grab)
     }
 }
 
+void ClipModel::setSelected(bool sel)
+{
+    QWriteLocker locker(&m_lock);
+    if (sel == selected) {
+        return;
+    }
+    selected = sel;
+    if (auto ptr = m_parent.lock()) {
+        if (m_currentTrackId != -1) {
+            QModelIndex ix = ptr->makeClipIndexFromID(m_id);
+            ptr->dataChanged(ix, ix, {TimelineModel::SelectedRole});
+        }
+    }
+}
+
 void ClipModel::clearOffset()
 {
     if (m_positionOffset != 0) {
@@ -760,3 +793,4 @@ int ClipModel::getMaxDuration() const
     }
     return m_producer->get_length();
 }
+
