@@ -164,22 +164,28 @@ bool TimelineFunctions::requestClipCut(const std::shared_ptr<TimelineItemModel>
     // Remove locked items
     std::unordered_set<int> clips;
     for (int cid : clipselect) {
+        if (!timeline->isClip(cid)) {
+            continue;
+        }
         int tk = timeline->getClipTrackId(cid);
         if (tk != -1 && !timeline->getTrackById_const(tk)->isLocked()) {
             clips.insert(cid);
         }
     }
+    // We need to call clearSelection before attempting the split or the group split will be corrupted by the selection group (no undo support)
     timeline->requestClearSelection();
+
     std::unordered_set<int> topElements;
     std::transform(clips.begin(), clips.end(), std::inserter(topElements, topElements.begin()), [&](int id) { return timeline->m_groups->getRootId(id); });
 
-    // We need to call clearSelection before attempting the split or the group split will be corrupted by the selection group (no undo support)
-    timeline->requestClearSelection();
     int count = 0;
     QList<int> newIds;
     int mainId = -1;
     QList<int> clipsToCut;
     for (int cid : clips) {
+        if (!timeline->isClip(cid)) {
+            continue;
+        }
         int start = timeline->getClipPosition(cid);
         int duration = timeline->getClipPlaytime(cid);
         if (start < position && (start + duration) > position) {
@@ -211,6 +217,7 @@ bool TimelineFunctions::requestClipCut(const std::shared_ptr<TimelineItemModel>
         auto criterion = [timeline, position](int cid) { return timeline->getClipPosition(cid) < position; };
         bool res = true;
         for (const int topId : topElements) {
+            qDebug()<<"// CHECKING REGROUP ELMENT: "<<topId<<", ISCLIP: "<<timeline->isClip(topId)<<timeline->isGroup(topId);
             res = res && timeline->m_groups->split(topId, criterion, undo, redo);
         }
         if (!res) {
@@ -246,7 +253,8 @@ bool TimelineFunctions::requestSpacerEndOperation(const std::shared_ptr<Timeline
     // Start undoable command
     std::function<bool(void)> undo = []() { return true; };
     std::function<bool(void)> redo = []() { return true; };
-    int res = timeline->requestClipsGroup(clips, undo, redo, GroupType::Selection);
+    //int res = timeline->requestClipsGroup(clips, undo, redo, GroupType::Selection);
+    int res = timeline->m_groups->getRootId(itemId);
     bool final = false;
     if (res > -1 || clips.size() == 1) {
         if (clips.size() > 1) {
@@ -292,7 +300,7 @@ bool TimelineFunctions::extractZone(const std::shared_ptr<TimelineItemModel> &ti
 }
 
 bool TimelineFunctions::insertZone(const std::shared_ptr<TimelineItemModel> &timeline, QList<int> trackIds, const QString &binId, int insertFrame, QPoint zone,
-                                   bool overwrite)
+                                   bool overwrite, bool useTargets)
 {
     // Start undoable command
     std::function<bool(void)> undo = []() { return true; };
@@ -336,7 +344,7 @@ bool TimelineFunctions::insertZone(const std::shared_ptr<TimelineItemModel> &tim
         if (!trackIds.isEmpty()) {
             int newId = -1;
             QString binClipId = QString("%1/%2/%3").arg(binId).arg(zone.x()).arg(zone.y() - 1);
-            result = timeline->requestClipInsertion(binClipId, trackIds.first(), insertFrame, newId, true, true, true, undo, redo);
+            result = timeline->requestClipInsertion(binClipId, trackIds.first(), insertFrame, newId, true, true, useTargets, undo, redo);
         }
         if (result) {
             pCore->pushUndo(undo, redo, overwrite ? i18n("Overwrite zone") : i18n("Insert zone"));
@@ -392,7 +400,6 @@ bool TimelineFunctions::removeSpace(const std::shared_ptr<TimelineItemModel> &ti
         }
         ++it;
     }
-
     bool result = false;
     if (!clips.empty()) {
         int clipId = *clips.begin();
@@ -570,7 +577,7 @@ bool TimelineFunctions::changeClipState(const std::shared_ptr<TimelineItemModel>
     // For the state change to work, we need to unplant/replant the clip
     bool result = true;
     if (track > -1) {
-        result = timeline->getTrackById(track)->requestClipDeletion(clipId, true, invalidate, local_undo, local_redo);
+        result = timeline->getTrackById(track)->requestClipDeletion(clipId, true, invalidate, local_undo, local_redo, false, false);
     }
     result = timeline->m_allClips[clipId]->setClipState(status, local_undo, local_redo);
     if (result && track > -1) {
@@ -698,25 +705,25 @@ void TimelineFunctions::setCompositionATrack(const std::shared_ptr<TimelineItemM
     int start = timeline->getItemPosition(cid);
     int end = start + timeline->getItemPlaytime(cid);
     Fun local_redo = [timeline, cid, aTrack, autoTrack, start, end]() {
+        timeline->unplantComposition(cid);
         QScopedPointer<Mlt::Field> field(timeline->m_tractor->field());
         field->lock();
         timeline->getCompositionPtr(cid)->setForceTrack(!autoTrack);
         timeline->getCompositionPtr(cid)->setATrack(aTrack, aTrack <= 0 ? -1 : timeline->getTrackIndexFromPosition(aTrack - 1));
         field->unlock();
-        QModelIndex modelIndex = timeline->makeCompositionIndexFromID(cid);
-        timeline->dataChanged(modelIndex, modelIndex, {TimelineModel::ItemATrack});
+        timeline->replantCompositions(cid, true);
         timeline->invalidateZone(start, end);
         timeline->checkRefresh(start, end);
         return true;
     };
     Fun local_undo = [timeline, cid, previousATrack, previousAutoTrack, start, end]() {
+        timeline->unplantComposition(cid);
         QScopedPointer<Mlt::Field> field(timeline->m_tractor->field());
         field->lock();
         timeline->getCompositionPtr(cid)->setForceTrack(previousAutoTrack == 0);
         timeline->getCompositionPtr(cid)->setATrack(previousATrack, previousATrack <= 0 ? -1 : timeline->getTrackIndexFromPosition(previousATrack - 1));
         field->unlock();
-        QModelIndex modelIndex = timeline->makeCompositionIndexFromID(cid);
-        timeline->dataChanged(modelIndex, modelIndex, {TimelineModel::ItemATrack});
+        timeline->replantCompositions(cid, true);
         timeline->invalidateZone(start, end);
         timeline->checkRefresh(start, end);
         return true;
