@@ -155,6 +155,7 @@ public:
         EffectNamesRole,    // track and clip only
         EffectsEnabledRole, // track and clip only
         GrabbedRole,        /// clip+composition only
+        SelectedRole,       /// clip+composition only
         TrackActiveRole,    /// track only
         AudioRecordRole     /// track only
     };
@@ -356,7 +357,7 @@ public:
 
     /* Same function, but accumulates undo and redo, and doesn't check
        for group*/
-    bool requestClipMove(int clipId, int trackId, int position, bool updateView, bool invalidateTimeline, bool finalMove, Fun &undo, Fun &redo);
+    bool requestClipMove(int clipId, int trackId, int position, bool updateView, bool invalidateTimeline, bool finalMove, Fun &undo, Fun &redo, bool groupMove = false);
     bool requestCompositionMove(int transid, int trackId, int compositionTrack, int position, bool updateView, bool finalMove, Fun &undo, Fun &redo);
 
     /* When timeline edit mode is insert or overwrite, we fake the move (as it will overlap existing clips, and only process the real move on drop */
@@ -404,6 +405,9 @@ protected:
        @param state: The desired clip state (original, audio/video only).
      */
     bool requestClipCreation(const QString &binClipId, int &id, PlaylistState::ClipState state, double speed, Fun &undo, Fun &redo);
+    
+    /* @brief Switch item selection status */
+    void setSelected(int itemId, bool sel);
 
 public:
     /* @brief Deletes the given clip or composition from the timeline.
