@@ -244,8 +244,9 @@ void TimelineController::selectCurrentItem(ObjectType type, bool select, bool ad
 QList<int> TimelineController::selection() const
 {
     if (!m_root) return QList<int>();
+    std::unordered_set<int> sel = m_model->getCurrentSelection();
     QList<int> items;
-    for (int id : m_model->getCurrentSelection()) {
+    for (int id : sel) {
         items << id;
     }
     return items;
@@ -343,10 +344,7 @@ int TimelineController::insertNewComposition(int tid, int clipId, int offset, co
         }
     }
     position = qMin(minimum + clip_duration - 1, position);
-    int duration = pCore->currentDoc()->getFramePos(KdenliveSettings::transition_duration());
-    if (duration == 0) {
-        duration = m_model->getTrackById_const(tid)->suggestCompositionLength(position);
-    }
+    int duration = qMin(pCore->currentDoc()->getFramePos(KdenliveSettings::transition_duration()), m_model->getTrackById_const(tid)->suggestCompositionLength(position));
     int lowerVideoTrackId = m_model->getPreviousVideoTrackIndex(tid);
     bool revert = offset > clip_duration / 2;
     if (lowerVideoTrackId > 0) {
@@ -626,6 +624,7 @@ void TimelineController::setInPoint()
 
     int cursorPos = timelinePosition();
     const auto selection = m_model->getCurrentSelection();
+    bool selectionFound = false;
     if (!selection.empty()) {
         for (int id : selection) {
             int start = m_model->getItemPosition(id);
@@ -634,6 +633,26 @@ void TimelineController::setInPoint()
             }
             int size = start + m_model->getItemPlaytime(id) - cursorPos;
             m_model->requestItemResize(id, size, false, true, 0, false);
+            selectionFound = true;
+        }
+    }
+    if (!selectionFound) {
+        if (m_activeTrack >= 0) {
+            int cid = m_model->getClipByPosition(m_activeTrack, cursorPos);
+            if (cid < 0) {
+                // Check first item after timeline position
+                int maximumSpace = m_model->getTrackById_const(m_activeTrack)->getBlankEnd(cursorPos);
+                if (maximumSpace < INT_MAX) {
+                    cid = m_model->getClipByPosition(m_activeTrack, maximumSpace + 1);
+                }
+            }
+            if (cid >= 0) {
+                int start = m_model->getItemPosition(cid);
+                if (start != cursorPos) {
+                    int size = start + m_model->getItemPlaytime(cid) - cursorPos;
+                    m_model->requestItemResize(cid, size, false, true, 0, false);
+                }
+            }
         }
     }
 }
@@ -652,6 +671,7 @@ void TimelineController::setOutPoint()
     }
     int cursorPos = timelinePosition();
     const auto selection = m_model->getCurrentSelection();
+    bool selectionFound = false;
     if (!selection.empty()) {
         for (int id : selection) {
             int start = m_model->getItemPosition(id);
@@ -660,6 +680,24 @@ void TimelineController::setOutPoint()
             }
             int size = cursorPos - start;
             m_model->requestItemResize(id, size, true, true, 0, false);
+            selectionFound = true;
+        }
+    }
+    if (!selectionFound) {
+        if (m_activeTrack >= 0) {
+            int cid = m_model->getClipByPosition(m_activeTrack, cursorPos);
+            if (cid < 0) {
+                // Check first item after timeline position
+                int minimumSpace = m_model->getTrackById_const(m_activeTrack)->getBlankStart(cursorPos);
+                cid = m_model->getClipByPosition(m_activeTrack, qMax(0, minimumSpace - 1));
+            }
+            if (cid >= 0) {
+                int start = m_model->getItemPosition(cid);
+                if (start + m_model->getItemPlaytime(cid) != cursorPos) {
+                    int size = cursorPos - start;
+                    m_model->requestItemResize(cid, size, true, true, 0, false);
+                }
+            }
         }
     }
 }
@@ -1480,6 +1518,7 @@ void TimelineController::changeItemSpeed(int clipId, double speed)
 void TimelineController::switchCompositing(int mode)
 {
     // m_model->m_tractor->lock();
+    pCore->currentDoc()->setDocumentProperty(QStringLiteral("compositing"), QString::number(mode));    
     QScopedPointer<Mlt::Service> service(m_model->m_tractor->field());
     Mlt::Field *field = m_model->m_tractor->field();
     field->lock();
@@ -1499,7 +1538,7 @@ void TimelineController::switchCompositing(int mode)
             QStringLiteral("0=0/0:%1x%2").arg(m_model->m_tractor->profile()->width()).arg(m_model->m_tractor->profile()->height());
 
         // Loop through tracks
-        for (int track = 1; track < m_model->getTracksCount(); track++) {
+        for (int track = 0; track < m_model->getTracksCount(); track++) {
             if (m_model->getTrackById(m_model->getTrackIndexFromPosition(track))->getProperty("kdenlive:audio_track").toInt() == 0) {
                 // This is a video track
                 Mlt::Transition t(*m_model->m_tractor->profile(),
@@ -1600,7 +1639,7 @@ bool TimelineController::insertClipZone(const QString &binId, int tid, int posit
     if (aTrack > -1) {
         target_tracks << aTrack;
     }
-    return TimelineFunctions::insertZone(m_model, target_tracks, binId, position, QPoint(in, out), m_model->m_editMode == TimelineMode::OverwriteEdit);
+    return TimelineFunctions::insertZone(m_model, target_tracks, binId, position, QPoint(in, out), m_model->m_editMode == TimelineMode::OverwriteEdit, false);
 }
 
 int TimelineController::insertZone(const QString &binId, QPoint zone, bool overwrite)
@@ -2096,19 +2135,37 @@ const QString TimelineController::getAssetName(const QString &assetId, bool isTr
 
 void TimelineController::grabCurrent()
 {
-    if (m_model->getCurrentSelection().empty()) {
+    std::unordered_set<int> selection = m_model->getCurrentSelection();
+    if (selection.empty()) {
         // TODO: error displayMessage
         return;
     }
-    int id = *m_model->getCurrentSelection().begin();
-    while (m_model->isGroup(id)) {
-        id = *m_model->m_groups->getLeaves(id).begin();
+    std::unordered_set<int> items;
+    for (int i : selection) {
+        if (m_model->isGroup(i)) {
+            auto children = m_model->m_groups->getLeaves(i);
+            items.insert(children.begin(), children.end());
+        } else {
+            items.insert(i);
+        }
     }
-    if (m_model->isClip(id)) {
-        std::shared_ptr<ClipModel> clip = m_model->getClipPtr(id);
+    int mainId = 0;
+    if (m_activeTrack > 0) {
+        for (int i : items) {
+            if (m_model->getItemTrackId(i) == m_activeTrack) {
+                mainId = i;
+                break;
+            }
+        }
+    }
+    if (mainId == 0) {
+        mainId = *items.begin();
+    }
+    if (m_model->isClip(mainId)) {
+        std::shared_ptr<ClipModel> clip = m_model->getClipPtr(mainId);
         clip->setGrab(!clip->isGrabbed());
-    } else if (m_model->isComposition(id)) {
-        std::shared_ptr<CompositionModel> clip = m_model->getCompositionPtr(id);
+    } else if (m_model->isComposition(mainId)) {
+        std::shared_ptr<CompositionModel> clip = m_model->getCompositionPtr(mainId);
         clip->setGrab(!clip->isGrabbed());
     }
 }
@@ -2147,7 +2204,7 @@ bool TimelineController::endFakeMove(int clipId, int position, bool updateView,
     int currentTrack = m_model->m_allClips[clipId]->getCurrentTrackId();
     bool res = true;
     if (currentTrack > -1) {
-        res = res && m_model->getTrackById(currentTrack)->requestClipDeletion(clipId, updateView, invalidateTimeline, undo, redo);
+        res = res && m_model->getTrackById(currentTrack)->requestClipDeletion(clipId, updateView, invalidateTimeline, undo, redo, false, false);
     }
     if (m_model->m_editMode == TimelineMode::OverwriteEdit) {
         res = res && TimelineFunctions::liftZone(m_model, trackId, QPoint(position, position + duration), undo, redo);
@@ -2232,7 +2289,7 @@ bool TimelineController::endFakeGroupMove(int clipId, int groupId, int delta_tra
                 int duration = m_model->m_allClips[item]->getPlaytime();
                 min = min < 0 ? old_position[item] + delta_pos : qMin(min, old_position[item] + delta_pos);
                 max = max < 0 ? old_position[item] + delta_pos + duration : qMax(max, old_position[item] + delta_pos + duration);
-                ok = ok && m_model->getTrackById(old_trackId)->requestClipDeletion(item, updateThisView, finalMove, undo, redo);
+                ok = ok && m_model->getTrackById(old_trackId)->requestClipDeletion(item, updateThisView, finalMove, undo, redo, false, false);
             } else {
                 // ok = ok && getTrackById(old_trackId)->requestCompositionDeletion(item, updateThisView, local_undo, local_redo);
                 old_position[item] = m_model->m_allCompositions[item]->getPosition();
