@@ -82,7 +82,7 @@ public:
     void setRoot(QQuickItem *root);
     /** @brief Edit an item's in/out points with a dialog
      */
-    Q_INVOKABLE void editItemDuration(int itemId);
+    Q_INVOKABLE void editItemDuration(int itemId = -1);
 
     /** @brief Returns the topmost track containing a selected item (-1 if selection is embty) */
     Q_INVOKABLE int selectedTrack() const;
@@ -181,7 +181,7 @@ public:
      */
     Q_INVOKABLE QList<int> insertClips(int tid, int position, const QStringList &binIds, bool logUndo, bool refreshView);
     Q_INVOKABLE void copyItem();
-    Q_INVOKABLE bool pasteItem();
+    Q_INVOKABLE bool pasteItem(int position = -1, int tid = -1);
     /* @brief Request inserting a new composition in timeline (dragged from compositions list)
        @param tid is the destination track
        @param position is the timeline position
@@ -209,9 +209,11 @@ public:
     Q_INVOKABLE void triggerAction(const QString &name);
 
     /* @brief Returns id of the timeline selcted clip if there is only 1 clip selected
-     * or an AVSplit group. Returns -1 otherwise
+     * or an AVSplit group. If allowComposition is true, returns composition id if 
+     * only 1 is selected, otherwise returns -1. If restrictToCurrentPos is true, it will
+     * only return the id if timeline cursor is inside item
      */
-    int getMainSelectedClip();
+    int getMainSelectedItem(bool restrictToCurrentPos = true, bool allowComposition = false);
 
     /* @brief Do we want to display video thumbnails
      */
@@ -450,6 +452,8 @@ public:
     QStringList getThumbKeys();
     /** @brief Returns true if a drag operation is currently running in timeline */
     bool dragOperationRunning();
+    /** @brief Disconnect some stuff before closing project */
+    void prepareClose();
 
 public slots:
     void resetView();
